RestrictAccess

Trait RestrictAccess 

pub trait RestrictAccess<To>: Access {
    type Restricted: Access;
}
A trait for restricting one Access type to another Access type.

Restricting Self to To results in Self::Restricted.

Restriction is a symmetric operation which is denoted by ∩, as it is the intersection of permissions. The following table holds:

Required Associated Types

type Restricted: Access

The resulting Access type of Self restricted to To.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors